<?php
namespace Teknisa\CADFIS\Factories;

use Doctrine\ORM\EntityManager;

class Ger00200EmpresaFactory {
    #default service
    protected $connection;
    private $entityManager;
    
    public function __construct(EntityManager $entityManager) {
        #initializes default service
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;

    }
    
    public function getInscrEstad($cdinscesta, $cdempresa, $nrorg) {
        $sql = 'SELECT CDINSCESTA,
                CDEMPRESA,
                NRORG,
                DSDIRCERTIFICADO
        FROM INSCRESTAD
        WHERE CDINSCESTA = :P_CDINSCESTA
        AND CDEMPRESA    = :P_CDEMPRESA
        AND NRORG        = :P_NRORG';
        
        $params = array(
            'P_CDINSCESTA' => $cdinscesta,
            'P_CDEMPRESA'  => $cdempresa,
            'P_NRORG'      => $nrorg
        );

        $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }
    
    public function getBairro($sequential, $country, $state, $county) {
        $sql = 'SELECT *
                    FROM BAIRRO
                    WHERE CDBAIRRO      = :CDBAIRRO
                    AND CDPAIS          = :CDPAIS
                    AND SGESTADO        = :SGESTADO
                    AND CDMUNICIPIO     = :CDMUNICIPIO';
        
        $params = array(
            'CDBAIRRO' => $sequential,
            'CDPAIS'  => $country,
            'SGESTADO'      => $state,
            'CDMUNICIPIO'      => $county
        );

        $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }
    
    public function getBairroByName($country, $state, $county, $neighborhood) {
        $sql = 'SELECT *
                    FROM BAIRRO
                    WHERE CDPAIS          = :CDPAIS
                    AND SGESTADO        = :SGESTADO
                    AND CDMUNICIPIO     = :CDMUNICIPIO
                    AND NMBAIRRO        = :NMBAIRRO';
        
        $params = array(
            'CDPAIS'        => $country,
            'SGESTADO'      => $state,
            'CDMUNICIPIO'   => $county,
            'NMBAIRRO'      => $neighborhood
        );

        $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }
    public function select (){
    $sql = "SELECT CDEMPRESA,
            CASE IDOPTSIMPLES WHEN 'S' THEN '1' ELSE '3' END AS CDSITUCRT
         FROM EMPRESA E
         WHERE NOT EXISTS (SELECT *
                         FROM PARAMEMPRESA P
                        WHERE E.CDEMPRESA = P.CDEMPRESA)";
                       
         $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute();
        return $query->fetchAll();
                        
    
    }
    
    public function selectparamempresa ($rows){
    $sql = "SELECT * FROM PARAMEMPRESA
                WHERE CDEMPRESA = :CDEMPRESA";
                
    $params = array(
            'CDEMPRESA'  => $rows
        );
                       
    $query = $this->entityManager->getConnection()->prepare($sql);
    $query->execute($params);
    
    return $query->fetchAll();
                        
    
    }
    
    public function insertparamempresa ($cdempresa, $cdsitucrt){
        $sql = "INSERT INTO PARAMEMPRESA 
                       ( CDSITUCRT, CDEMPRESA)
                        VALUES (
                            :CDSITUCRT,
                            :CDEMPRESA)";
                            
        $params = array(
            'CDSITUCRT'  => $cdsitucrt,
            'CDEMPRESA' => $cdempresa
        );
        $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
    }
    
    public function updateparamempresa ($cdempresa, $cdsitucrt){
        $sql = "UPDATE PARAMEMPRESA 
					SET CDSITUCRT = :CDSITUCRT
					WHERE CDEMPRESA = :CDEMPRESA";
					
		$params = array(
            'CDSITUCRT'  => $cdsitucrt,
            'CDEMPRESA' => $cdempresa
        );
        $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
    }
    
    
    public function insert (){
        $sql = "INSERT INTO PARAMEMPRESA
           (CDEMPRESA, CDSITUCRT)
           (SELECT CDEMPRESA, CASE IDOPTSIMPLES WHEN 'S' THEN '1' ELSE '3' END AS CDSITUCRT
              FROM EMPRESA E
             WHERE NOT EXISTS (SELECT *
                                 FROM PARAMEMPRESA P
                                WHERE E.CDEMPRESA = P.CDEMPRESA))";
                       
        $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute();
                        
    
    }
    public function updateDsDirCert($cdinscesta, $cdempresa, $nrorg, $dsdircert) {
        $sql = 'UPDATE INSCRESTAD
        SET DSDIRCERTIFICADO    = :P_DSDIRCERTIFICADO
        WHERE CDINSCESTA = :P_CDINSCESTA
        AND CDEMPRESA    = :P_CDEMPRESA
        AND NRORG        = :P_NRORG';
        
        $params = array(
            'P_DSDIRCERTIFICADO'  => $dsdircert,
            'P_CDINSCESTA' => $cdinscesta,
            'P_CDEMPRESA'  => $cdempresa,
            'P_NRORG'      => $nrorg
        );
        $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
    }
    
    public function updateDsDirLogoEmpresa($cdempresa, $nrorg, $dsdirlogomarca, $name) {
        $sql = 'UPDATE EMPRESA
                SET
                    DSDIRLOGOMARCA = :P_DSDIRLOGOMARCA,
                    DSARQLOGOEMP   = :P_DSARQLOGOEMP
                WHERE
                    CDEMPRESA = :P_CDEMPRESA
                    AND NRORG = :P_NRORG';
        
        $params = array(
            'P_DSARQLOGOEMP' => $name,
            'P_DSDIRLOGOMARCA'  => $dsdirlogomarca,
            'P_CDEMPRESA'  => $cdempresa,
            'P_NRORG'      => $nrorg
        );
        $query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
    }
    


}