<?php
namespace Teknisa\CADFIS\Strategies;

use Teknisa\Libs\Util\Environment;
use Teknisa\CADFIS\Strategies\GeneralStrategy;
use Teknisa\CADFIS\Services\ProdFornService as ProdFornService;

class ProdFornStrategy extends GeneralStrategy implements Interfaces\IStrategy
{
    protected $service;
    protected $errors = array();
    
    public function __construct(ProdFornService $service, Environment $environment)
    {
		$this->service = $service;
		$this->environment = $environment;
	}
	
	public function validate(&$data)
    {
        //parent::verifyIsEmpty($data);
        
        foreach ($data as &$row) {
            parent::verifyIsEmpty($row, $row["ROWNUM"], ['IDTPIJURFORN', 'NRINSJURFORN', 'CDARVPROD']);
            parent::verifyIdTpIJurForn($row, $row["ROWNUM"]);
            parent::verifyNrInsJurForn($row, $row["ROWNUM"]);
            parent::concatCdForneced($row);
            self::verifyFornecedorExists($row, $row["ROWNUM"]);
            parent::verifyCdProduto($row, $row["ROWNUM"]);
            self::verifyProdFornExists($row, $row["ROWNUM"]);
            self::verifyQtDiasEntr($row, $row["ROWNUM"]);
            self::verifyQtMinAF($row, $row["ROWNUM"]);
            parent::verifyUnidade($row, $row["ROWNUM"]);
            self::verifyVrArredCmpFo($row, $row["ROWNUM"]);
            self::verifyVrPerPi($row, $row["ROWNUM"]);
            self::verifyArredEmpe($row, $row["ROWNUM"]);
            self::verifyPerVarPreco($row, $row["ROWNUM"]);
            self::verifyNrDiasVal($row, $row["ROWNUM"]);
            
            
            $row['ERROS'] = $this->errors;
            
            parent::clearErrors();
        }
    }
    
    private function verifyFornecedorExists($row, $rowNum)
    {
        if (!$this->service->verifyFornecedorExists($row)) {
            parent::setError($rowNum, 'NRINSJURFORN', $row['NRINSJURFORN'], "UNREGISTERED");
        }
    }
    
    private function verifyProdFornExists($row, $rowNum)
    {
        if(!is_null($row['NRINSJURFORN']) && !is_null($row['CDARVPROD'])) {
            if ($this->service->verifyProdFornExists($row)) {
                parent::setError($rowNum, 'NRINSJURFORN/CDARVPROD', $row['NRINSJURFORN'].'/'.$row['CDARVPROD'], "ALREADY_REGISTERED");
            }
        }
    }
    
    private function verifyVrArredCmpFo($row, $rowNum)
    {
        $columnName = 'VRARREDCMPFO';
        if (!is_null($row[$columnName])) {
            parent::verifyNumericos($row, $rowNum, $columnName);
            parent::verifyGreaterThanZero($row, $rowNum, $columnName);
        }
    }
    
    private function verifyVrPerPi($row, $rowNum)
    {
        $columnName = 'VRPERPIPRFO';
        if (!is_null($row[$columnName])) {
            parent::verifyNumericos($row, $rowNum, $columnName);
            parent::verifyLessThan100($row, $rowNum, $columnName);
        }
    }
    
    private function verifyArredEmpe($row, $rowNum)
    {
        $columnName = 'VRARREDEMPE';
        if (!is_null($row[$columnName])) {
            parent::verifyNumericos($row, $rowNum, $columnName);
            parent::verifyGreaterThanZero($row, $rowNum, $columnName);
        }
    }
    
    private function verifyPerVarPreco($row, $rowNum)
    {
        $columnName = 'VRPERVARPREPRFO';
        if (!is_null($row[$columnName])) {
            parent::verifyNumericos($row, $rowNum, $columnName);
            parent::verifyLessThan100($row, $rowNum, $columnName);
        }
    }
    
    private function verifyNrDiasVal($row, $rowNum)
    {
        $columnName = 'NRDIASVALPRFORN';
        if (!is_null($row[$columnName])) {
            parent::verifyNumericos($row, $rowNum, $columnName);
        }
    }
    
    private function verifyQtMinAF($row, $rowNum)
    {
        $columnName = 'QTMINAF';
        if (!is_null($row[$columnName])) {
            parent::verifyNumericos($row, $rowNum, $columnName);
        }
    }
    
    private function verifyQtDiasEntr($row, $rowNum)
    {
        $columnName = 'QTDIASENTR';
        if (!is_null($row[$columnName])) {
            parent::verifyNumericos($row, $rowNum, $columnName);
        }
    }
    
    public function save($data)
    {
        self::validate($data);
        parent::verifyExistErros($data);
        $this->service->saveImport($data);
    }
}